@@ -30,6 +30,7 @@
 #include <gdesktop-enums.h>
 
 #include "gs-prefs.h"
+#include "gs-debug.h"
 
 static void gs_prefs_class_init (GSPrefsClass *klass);
 static void gs_prefs_init       (GSPrefs      *prefs);
@@ -39,9 +40,6 @@ static void gs_prefs_finalize   (GObject      *object);
 #define KEY_LOCK_DISABLE          "disable-lock-screen"
 #define KEY_USER_SWITCH_DISABLE   "disable-user-switching"
 
-#define GSM_SETTINGS_SCHEMA "org.gnome.desktop.session"
-#define KEY_ACTIVATE_DELAY "idle-delay"
-
 #define GS_SETTINGS_SCHEMA "org.gnome.desktop.screensaver"
 #define KEY_IDLE_ACTIVATION_ENABLED         "idle-activation-enabled"
 #define KEY_LOCK_ENABLED   "lock-enabled"
@@ -59,7 +57,6 @@ static void gs_prefs_finalize   (GObject      *object);
 struct GSPrefsPrivate
 {
         GSettings *settings;
-        GSettings *session_settings;
         GSettings *lockdown;
 };
 
@@ -136,7 +133,7 @@ _gs_prefs_set_lock_timeout (GSPrefs *prefs,
         if (value > 480)
                 value = 480;
 
-        prefs->lock_timeout = value * 60000;
+        prefs->lock_timeout = value * 1000;
 }
 
 static void
@@ -225,7 +222,7 @@ _gs_prefs_set_logout_timeout (GSPrefs *prefs,
         if (value > 480)
                 value = 480;
 
-        prefs->logout_timeout = value * 60000;
+        prefs->logout_timeout = value * 1000;
 }
 
 static void
@@ -258,12 +255,6 @@ gs_prefs_load_from_settings (GSPrefs *prefs)
         bvalue = g_settings_get_boolean (prefs->priv->settings, KEY_LOCK_ENABLED);
         _gs_prefs_set_lock_enabled (prefs, bvalue);
 
-        bvalue = g_settings_get_boolean (prefs->priv->lockdown, KEY_LOCK_DISABLE);
-        _gs_prefs_set_lock_disabled (prefs, bvalue);
-
-        bvalue = g_settings_get_boolean (prefs->priv->lockdown, KEY_USER_SWITCH_DISABLE);
-        _gs_prefs_set_user_switch_disabled (prefs, bvalue);
-
         uvalue = _gs_settings_get_uint (prefs->priv->settings, KEY_LOCK_DELAY);
         _gs_prefs_set_lock_timeout (prefs, uvalue);
 
@@ -295,6 +286,15 @@ gs_prefs_load_from_settings (GSPrefs *prefs)
 
         bvalue = g_settings_get_boolean (prefs->priv->settings, KEY_USER_SWITCH_ENABLED);
         _gs_prefs_set_user_switch_enabled (prefs, bvalue);
+
+        /* Lockdown keys */
+
+        bvalue = g_settings_get_boolean (prefs->priv->lockdown, KEY_LOCK_DISABLE);
+        _gs_prefs_set_lock_disabled (prefs, bvalue);
+
+        bvalue = g_settings_get_boolean (prefs->priv->lockdown, KEY_USER_SWITCH_DISABLE);
+        _gs_prefs_set_user_switch_disabled (prefs, bvalue);
+
 }
 
 static void
@@ -322,7 +322,7 @@ key_changed_cb (GSettings   *settings,
 
                 enabled = g_settings_get_boolean (settings, key);
                 _gs_prefs_set_lock_enabled (prefs, enabled);
-
+                gs_debug ("lock-enabled=%d",enabled);
         } else if (strcmp (key, KEY_LOCK_DISABLE) == 0) {
 
                 gboolean disabled;
@@ -388,6 +388,7 @@ key_changed_cb (GSettings   *settings,
 
         } else {
                 g_warning ("Config key not handled: %s", key);
+                return;
         }
 
         g_signal_emit (prefs, signals [CHANGED], 0);
@@ -403,11 +404,6 @@ gs_prefs_init (GSPrefs *prefs)
                           "changed",
                           G_CALLBACK (key_changed_cb),
                           prefs);
-        prefs->priv->session_settings  = g_settings_new (GSM_SETTINGS_SCHEMA);
-        g_signal_connect (prefs->priv->session_settings,
-                          "changed",
-                          G_CALLBACK (key_changed_cb),
-                          prefs);
         prefs->priv->lockdown          = g_settings_new (LOCKDOWN_SETTINGS_SCHEMA);
         g_signal_connect (prefs->priv->lockdown,
                           "changed",
@@ -442,10 +438,6 @@ gs_prefs_finalize (GObject *object)
                 g_object_unref (prefs->priv->settings);
                 prefs->priv->settings = NULL;
         }
-        if (prefs->priv->session_settings) {
-                g_object_unref (prefs->priv->session_settings);
-                prefs->priv->session_settings = NULL;
-        }
         if (prefs->priv->lockdown) {
                 g_object_unref (prefs->priv->lockdown);
                 prefs->priv->lockdown = NULL;
